@@ -35,10 +35,9 @@ except ImportError as e:
 TRT8 = 8
 TRT7 = 7
 
-# TRT_LOGGER = trt.Logger(trt.Logger.VERBOSE)
-# TRT_LOGGER = trt.Logger(trt.Logger.INFO)
-TRT_LOGGER = trt.Logger()
-
+TRT_LOGGER = trt.Logger(trt.Logger.INFO)
+# TRT_LOGGER = trt.Logger()
+trt.init_libnvinfer_plugins(TRT_LOGGER, namespace="")
 # Allocate host and device buffers, and create a stream.
 
 
@@ -82,7 +81,7 @@ def allocate_buffers_v2(engine):
     bindings = []
     stream = cuda.Stream()
     for binding in engine:
-        size = trt.volume(engine.get_binding_shape(binding)) * engine.max_batch_size
+        size = abs(trt.volume(engine.get_binding_shape(binding))) * engine.max_batch_size
         dtype = trt.nptype(engine.get_binding_dtype(binding))
         # Allocate host and device buffers
         host_mem = cuda.pagelocked_empty(size, dtype)
@@ -95,6 +94,7 @@ def allocate_buffers_v2(engine):
         else:
             outputs.append(HostDeviceMem(host_mem, device_mem))
     return inputs, outputs, bindings, stream
+    # return inputs, outputs, bindings
 
 
 # do inference  multi outputs
@@ -113,6 +113,33 @@ def do_inference_v2(context, bindings, inputs, outputs, stream, input_tensor):
 
 
 def allocate_buffers_v2_dynamic(engine, is_explicit_batch=False, input_shape=None):
+    inputs = []
+    outputs = []
+    bindings = []
+    stream = cuda.Stream()
+    for binding in engine:
+        dims = engine.get_binding_shape(binding)
+        if dims[-1] == -1:
+            assert (
+                input_shape is not None
+            ), "dynamic trt engine must specific input_shape"
+            dims[-2], dims[-1] = input_shape
+        size = abs(trt.volume(dims)) * engine.max_batch_size
+        dtype = trt.nptype(engine.get_binding_dtype(binding))
+        # Allocate host and device buffers
+        host_mem = cuda.pagelocked_empty(size, dtype)
+        device_mem = cuda.mem_alloc(host_mem.nbytes)
+        # Append the device buffer to device bindings.
+        bindings.append(int(device_mem))
+        # Append to the appropriate list.
+        if engine.binding_is_input(binding):
+            inputs.append(HostDeviceMem(host_mem, device_mem))
+        else:
+            outputs.append(HostDeviceMem(host_mem, device_mem))
+    return inputs, outputs, bindings, stream
+
+
+def allocate_buffers_v2_dynamic_batch(engine, is_explicit_batch=False, max_batch=1):
     inputs = []
     outputs = []
     bindings = []
@@ -266,12 +293,11 @@ def build_engine_onnx_v2(
                             Please check if the ONNX model is compatible "
             logger.info("[INFO] Completed parsing of ONNX file")
             logger.info(
-                f"[INFO] Building an engine from file {onnx_file_path}; this may take a while..."
+                f"[INFO] Building an engine from file {onnx_file_path}, this may take a while..."
             )
 
             # build trt engine
-            builder.max_batch_size = max_batch_size
-
+            
             # set optimize profile for dynamic inputs
             profile = builder.create_optimization_profile()
             if opt_params is not None:
@@ -292,6 +318,9 @@ def build_engine_onnx_v2(
                     profile.set_shape(
                         input_tensor_name, min_shape, opt_shape, max_shape
                     )
+                    max_batch_size = max_shape[0]
+
+                builder.max_batch_size = max_batch_size
             trt_config.add_optimization_profile(profile)
 
             if trt_version == TRT8:
@@ -302,12 +331,16 @@ def build_engine_onnx_v2(
             if trt_version == TRT8:
                 if fp16_mode:
                     trt_config.set_flag(trt.BuilderFlag.FP16)
+                    logger.info('enabled fp16 mode.')
             else:
-                builder.fp16_mode = fp16_mode
+                if fp16_mode:
+                    builder.fp16_mode = fp16_mode
+                    logger.info('enabled fp16 mode.')
 
             if int8_mode:
                 if trt_version == TRT8:
                     trt_config.set_flag(trt.BuilderFlag.INT8)
+                    logger.info('enabled int8 mode.')
                 else:
                     builder.fp16_mode = fp16_mode
 
@@ -318,7 +351,7 @@ def build_engine_onnx_v2(
                     calibration_stream, calibration_table_path
                 )
                 # builder.int8_calibrator  = Calibrator(calibration_stream, calibration_table_path)
-                logger.info("[INFO] Int8 mode enabled")
+                logger.info("Int8 mode enabled")
 
             engine = None
             if trt_version == TRT8:
@@ -327,9 +360,9 @@ def build_engine_onnx_v2(
                 engine = builder.build_cuda_engine(network)
 
             if engine is None:
-                logger.info("[INFO] Failed to create the engine")
+                logger.info("Failed to create the engine")
                 return None
-            logger.info("[INFO] Completed creating the engine")
+            logger.info("Completed creating the engine")
             if save_engine:
                 with open(engine_file_path, "wb") as f:
                     f.write(engine.serialize())
@@ -337,7 +370,7 @@ def build_engine_onnx_v2(
 
     if os.path.exists(engine_file_path):
         # If a serialized engine exists, load it instead of building a new one.
-        logger.info(f"[INFO] Reading engine from file {engine_file_path}")
+        logger.info(f"Reading engine from file {engine_file_path}")
         with open(engine_file_path, "rb") as f, trt.Runtime(TRT_LOGGER) as runtime:
             return runtime.deserialize_cuda_engine(f.read())
     else:
@@ -347,7 +380,7 @@ def build_engine_onnx_v2(
 def load_engine_from_local(engine_file_path):
     if os.path.exists(engine_file_path):
         # If a serialized engine exists, load it instead of building a new one.
-        logger.info(f"[INFO] Reading engine from file {engine_file_path}")
+        logger.info(f"Reading engine from file {engine_file_path}")
         with open(engine_file_path, "rb") as f, trt.Runtime(TRT_LOGGER) as runtime:
             return runtime.deserialize_cuda_engine(f.read())
     else:
@@ -376,7 +409,9 @@ def build_engine_onnx_v3(
     calibration_table_path="",
     save_engine=True,
 ):
-    """Attempts to load a serialized engine if available, otherwise builds a new TensorRT engine and saves it."""
+    """
+    this is deprecated.
+    """
     engine_file_path = os.path.join(
         os.path.dirname(onnx_file_path),
         os.path.basename(onnx_file_path).replace(".onnx", ".engine"),
@@ -395,9 +430,9 @@ def build_engine_onnx_v3(
             # parse onnx model file
             if not os.path.exists(onnx_file_path):
                 quit(f"[Error]ONNX file {onnx_file_path} not found")
-            logger.info(f"[INFO] Loading ONNX file from path {onnx_file_path}...")
+            logger.info(f"Loading ONNX file from path {onnx_file_path}...")
             with open(onnx_file_path, "rb") as model:
-                logger.info("[INFO] Beginning ONNX file parsing")
+                logger.info("Beginning ONNX file parsing")
                 parser.parse(model.read())
                 assert (
                     network.num_layers > 0
@@ -405,7 +440,7 @@ def build_engine_onnx_v3(
                             Please check if the ONNX model is compatible "
             logger.info("[INFO] Completed parsing of ONNX file")
             logger.info(
-                f"[INFO] Building an engine from file {onnx_file_path}, this may take a while..."
+                f"Building an engine from file {onnx_file_path}, this may take a while..."
             )
 
             # build trt engine
@@ -435,7 +470,7 @@ def build_engine_onnx_v3(
                     calibration_stream, calibration_table_path
                 )
                 # builder.int8_calibrator  = Calibrator(calibration_stream, calibration_table_path)
-                logger.info("[INFO] Int8 mode enabled")
+                logger.info("Int8 mode enabled")
 
             engine = None
             if trt_version == TRT8:
@@ -444,17 +479,18 @@ def build_engine_onnx_v3(
                 engine = builder.build_cuda_engine(network)
 
             if engine is None:
-                logger.info("[INFO] Failed to create the engine")
+                logger.info("Failed to create the engine")
                 return None
-            logger.info("[INFO] Completed creating the engine")
+            logger.info("Completed creating the engine")
             if save_engine:
+                logger.info(f"engine saved into: {engine_file_path}")
                 with open(engine_file_path, "wb") as f:
                     f.write(engine.serialize())
             return engine
 
     if os.path.exists(engine_file_path):
         # If a serialized engine exists, load it instead of building a new one.
-        logger.info(f"[INFO] Reading engine from file {engine_file_path}")
+        logger.info(f"Reading engine from file {engine_file_path}")
         with open(engine_file_path, "rb") as f, trt.Runtime(TRT_LOGGER) as runtime:
             return runtime.deserialize_cuda_engine(f.read())
     else:
